@@ -4,9 +4,9 @@ from .BaseFitter import BaseFitter
 from .Formatter import formatter as fmt
 
 __author__ = "Do Kester"
-__year__ = 2023
+__year__ = 2025
 __license__ = "GPL3"
-__version__ = "3.1.0"
+__version__ = "3.2.4"
 __url__ = "https://www.bayesicfitting.nl"
 __status__ = "Perpetual Beta"
 
@@ -28,7 +28,7 @@ __status__ = "Perpetual Beta"
 #  * Science System (HCSS), also under GPL3.
 #  *
 #  *    2003 - 2014 Do Kester, SRON (JAVA code)
-#  *    2016 - 2023 Do Kester
+#  *    2016 - 2025 Do Kester
 
 class Fitter( BaseFitter ):
     """
@@ -41,7 +41,7 @@ class Fitter( BaseFitter ):
 
     Examples
     --------
-    # assume x and y are numpy.asarray data arrays:
+    >>> # assume x and y are numpy.asarray data arrays:
     >>> x = numpy.arange( 100 )
     >>> y = numpy.arange( 100 ) // 4        # digitization noise
     >>> poly = PolynomialModel( 1 )         # line
