@@ -3,9 +3,9 @@ from . import Tools
 from .Tools import setAttribute as setatt
 
 __author__ = "Do Kester"
-__year__ = 2020
+__year__ = 2025
 __license__ = "GPL3"
-__version__ = "2.5.3"
+__version__ = "3.2.4"
 __url__ = "https://www.bayesicfitting.nl"
 __status__ = "Perpetual Beta"
 
@@ -27,7 +27,7 @@ __status__ = "Perpetual Beta"
 #  * Science System (HCSS), also under GPL3.
 #  *
 #  *    2003 - 2014 Do Kester, SRON (JAVA code)
-#  *    2016 - 2020 Do Kester
+#  *    2016 - 2025 Do Kester
 
 class NonLinearModel( Model ):
     """
@@ -44,9 +44,7 @@ class NonLinearModel( Model ):
 
     Attributes from Model
     ---------------------
-        parameters, stdevs, npchain
-        _next, _head, _operation
-        xUnit, yUnit (relegated to model)
+        parameters, stdevs, npchain, _next, _head, _operation, xUnit, yUnit 
 
     Attributes from FixedModel
     --------------------------
