@@ -5,9 +5,9 @@ from .NonLinearModel import NonLinearModel
 from astropy import units
 
 __author__ = "Do Kester"
-__year__ = 2020
+__year__ = 2025
 __license__ = "GPL3"
-__version__ = "2.5.3"
+__version__ = "3.2.4"
 __url__ = "https://www.bayesicfitting.nl"
 __status__ = "Perpetual Beta"
 
@@ -26,7 +26,7 @@ __status__ = "Perpetual Beta"
 #  *
 #  * The GPL3 license can be found at <http://www.gnu.org/licenses/>.
 #  *
-#  *    2017 - 2020 Do Kester
+#  *    2017 - 2025 Do Kester
 
 class ProductModel( NonLinearModel ):
     """
@@ -46,8 +46,8 @@ class ProductModel( NonLinearModel ):
     >>> smy = SplinesModel( yknots )
     >>> csm = ProductModel( [smx,smy] )
     >>> print csm.getNumberOfParameters( )      # ( nxk + order - 1 ) + ( nyk + order - 1 )
-    32
-    # ... fitter etc. see Fitter
+    >>> 32
+    >>> # ... fitter etc. see Fitter
 
     Category     mathematics/Fitting
 
