@@ -4,9 +4,9 @@ import math
 from .BaseFitter import BaseFitter
 
 __author__ = "Do Kester"
-__year__ = 2023
+__year__ = 2025
 __license__ = "GPL3"
-__version__ = "3.1.0"
+__version__ = "3.2.4"
 __url__ = "https://www.bayesicfitting.nl"
 __status__ = "Perpetual Beta"
 
@@ -28,7 +28,7 @@ __status__ = "Perpetual Beta"
 #  * Science System (HCSS), also under GPL3.
 #  *
 #  *    2003 - 2014 Do Kester, SRON (JAVA code)
-#  *    2016 - 2023 Do Kester
+#  *    2016 - 2025 Do Kester
 
 class QRFitter( BaseFitter ):
     """
@@ -56,7 +56,7 @@ class QRFitter( BaseFitter ):
 
     Examples
     --------
-    # assume x and y are numpy.asarray data arrays:
+    >>> # assume x and y are numpy.asarray data arrays:
     >>> x = numpy.asarray.range( 100 )
     >>> poly = PolynomialModel( 1 )                             # line
     >>> fitter = QRFitter( x, poly )
