@@ -2,9 +2,9 @@ from .KernelModel import KernelModel
 from .kernels.Sinc import Sinc
 
 __author__ = "Do Kester"
-__year__ = 2020
+__year__ = 2025
 __license__ = "GPL3"
-__version__ = "2.5.3"
+__version__ = "3.2.4"
 __url__ = "https://www.bayesicfitting.nl"
 __status__ = "Perpetual Beta"
 
@@ -27,7 +27,7 @@ __status__ = "Perpetual Beta"
 #  * Science System (HCSS), also under GPL3.
 #  *
 #  *    2003 - 2014 Do Kester, SRON (Java code)
-#  *    2016 - 2020 Do Kester
+#  *    2016 - 2025 Do Kester
 
 class SincModel( KernelModel ):
     """
@@ -36,16 +36,17 @@ class SincModel( KernelModel ):
 
         f( x:p ) = p_0 * sin( ( x - p_1 ) / p_2 ) / ( ( x - p_1 ) / p_2 )
 
-    where
+     where
         p_0 = amplitude
         p_1 = offset
         p_2 = width ( =Distance between first zero-crossings divided by 2 Pi. )
     As always x = input.
 
-    The parameters are initialized at {1.0, 0.0, 1.0}.
+    The parameters are initialized at [1.0, 0.0, 1.0].
+
     Parameter 2 ( width ) is always kept positive ( >=0 ).
 
-    SincModel() is syntactic sugar for
+     SincModel() is syntactic sugar for
         KernelModel( kernel=Sinc() )
     See @KernelModel
 
@@ -53,15 +54,11 @@ class SincModel( KernelModel ):
     --------
     >>> sinc = SincModel( )
     >>> print sinc.npchain
-    3
+    >>> 3
     >>> print( sinc( numpy.arange( 15, dtype=float )-7 ) )        # sinc function between [-7,+7]
-    [0,0,0,0,0,0,0,1,0,0,0,0,0,0,0]
+    >>> [0,0,0,0,0,0,0,1,0,0,0,0,0,0,0]
 
 
-    Attributes
-    ----------
-    none of its own
-
     Attributes from Model
     ---------------------
         npchain, parameters, stdevs, xUnit, yUnit
