@@ -4,11 +4,11 @@ import math
 from .Kernel import Kernel
 
 __author__ = "Do Kester"
-__year__ = 2017
+__year__ = 2025
 __license__ = "GPL3"
-__version__ = "0.9"
-__maintainer__ = "Do"
-__status__ = "Development"
+__version__ = "3.2.4"
+__url__ = "https://dokester.github.io/BayesicFitting/"
+__status__ = "Perpetual Beta"
 
 #  *
 #  *    This file is part of the BayesicFitting package.
@@ -29,15 +29,13 @@ __status__ = "Development"
 #  * Science System (HCSS), also under GPL3.
 #  *
 #  *    2013 - 2014 Do Kester, SRON (Java code)
-#  *    2016 - 2017 Do Kester
+#  *    2016 - 2025 Do Kester
 
 class Cosine( Kernel ):
     """
     Cosine is a Kernel function between [-1,1]; it is 0 elsewhere.
 
-        K( x ) = cos( 0.5 &pi; x )      if |x| < 1
-                 0                      elsewhere
-
+     K( x ) = cos( 0.5 &pi; x )  if |x| < 1 else 0
 
     """
     HALFPI = 0.5 * math.pi
@@ -46,26 +44,42 @@ class Cosine( Kernel ):
         """
         Constructor.
 
-        Using
+         Using
             integral = 4 / &pi;
             fwhm = 4.0 / 3.0
+
         """
         super( Cosine, self ).__init__( integral=4/math.pi, fwhm=4.0/3.0 )
 
     def result( self, x ):
+        """
+        Calculate the function.
+        
+        Parameters
+        ----------
+        x : array_like
+            at which to do the calculation
+        """
         return numpy.where( numpy.abs( x ) <= 1, numpy.cos( self.HALFPI * x ), 0.0 )
 
-    def resultsq( self, xsq ):
-        return self.result( numpy.sqrt( xsq ) )
-
     def partial( self, x ):
+        """
+        Return the partial derivative wrt input values.
+
+        Parameters
+        ----------
+        x : array-like
+            the input values
+        """
         return numpy.where( numpy.abs( x ) <= 1,
             -self.HALFPI * numpy.sin( self.HALFPI * x ), 0.0 )
 
     def isBound( self ):
+        """ Return True """
         return True
 
     def name( self ):
+        """ Return the name of the kernel """
         return str( "Cosine: cos( 0.5*PI*x ) if |x| < 1 else 0" )
 
 
