@@ -4,11 +4,11 @@ import math
 from .Kernel import Kernel
 
 __author__ = "Do Kester"
-__year__ = 2017
+__year__ = 2025
 __license__ = "GPL3"
-__version__ = "0.9"
-__maintainer__ = "Do"
-__status__ = "Development"
+__version__ = "3.2.4"
+__url__ = "https://dokester.github.io/BayesicFitting/"
+__status__ = "Perpetual Beta"
 
 #  *
 #  *    This file is part of the BayesicFitting package.
@@ -25,13 +25,13 @@ __status__ = "Development"
 #  *
 #  *    The GPL3 license can be found at <http://www.gnu.org/licenses/>.
 #  *
-#  *    2016 - 2017 Do Kester
+#  *    2016 - 2025 Do Kester
 
 class Huber( Kernel ):
     """
     Huber is an improper Kernel function
-        K( x ) = 1.0            if |x| < 1
-                 1.0 / |x|      elsewhere
+
+     K( x ) = 1.0 if |x| < 1 else 1.0 / |x|
 
     It is improper because the integral equals +inf.
 
@@ -44,29 +44,43 @@ class Huber( Kernel ):
 
         Improper Kernel.
 
-        Using
-            integral = inf
-            fwhm = 4
-            range = inf
+         Using
+         integral = inf
+         fwhm = 4
+         range = inf
         """
         super( Huber, self ).__init__( integral=math.inf, fwhm=4.0, range=math.inf )
 
     def result( self, x ):
+        """
+        Return the result for input values.
+
+        Parameters
+        ----------
+        x : array-like
+            input values
+        """
         ax = numpy.abs( x )
         return numpy.where( ax < 1, 1.0, 1.0 / ax )
 
-    def resultsq( self, xsq ):
-        ax = numpy.sqrt( xsq )
-        return numpy.where( ax < 1, 1.0, 1.0 / ax )
-
     def partial( self, x ):
+        """
+        Return the partial derivative wrt the input values.
+
+        Parameters
+        ----------
+        x : array-like
+            the input values
+        """
         ax = numpy.abs( x )
         return numpy.where( ax < 1, 0.0, -1.0 / ( x * ax ) )
 
     def isBound( self ):
+        """ Return False """
         return False
 
     def name( self ):
+        """ Return the name of the kernel """
         return str( "Huber: 1 if |x| < 1 else 1/|x|" )
 
 
