@@ -4,11 +4,11 @@ import math
 from .Kernel import Kernel
 
 __author__ = "Do Kester"
-__year__ = 2017
+__year__ = 2025
 __license__ = "GPL3"
-__version__ = "0.9"
-__maintainer__ = "Do"
-__status__ = "Development"
+__version__ = "3.2.4"
+__url__ = "https://dokester.github.io/BayesicFitting/"
+__status__ = "Perpetual Beta"
 
 #  *
 #  *    This file is part of the BayesicFitting package.
@@ -29,39 +29,64 @@ __status__ = "Development"
 #  * Science System (HCSS), also under GPL3.
 #  *
 #  *    2013 - 2014 Do Kester, SRON (Java code)
-#  *    2016 - 2017 Do Kester
+#  *    2016 - 2025 Do Kester
 
 class Parabola( Kernel ):
     """
     Parabola is a Kernel function between [-1,1]; it is 0 elsewhere.
 
-        K( x ) = ( 1-x^2 )      if |x| < 1
-                 0              elsewhere
+     K( x ) = ( 1-x^2 )      if |x| < 1 else 0
 
     """
     def __init__( self ) :
         """
         Constructor.
 
-        Using
-            integral = 4.0/3.0
-            fwhm = 2 sqrt( 0.5 )
+         Using
+         integral = 4.0/3.0
+         fwhm = 2 sqrt( 0.5 )
         """
         super( Parabola, self ).__init__( integral=4.0/3.0, fwhm=2 * math.sqrt(0.5) )
 
     def result( self, x ):
+        """
+        Return the result for input values.
+
+        Parameters
+        ----------
+        x : array-like
+            input values
+        """
         return self.resultsq( x * x )
 
     def resultsq( self, xsq ):
+        """
+        Return the result for squared input values.   
+
+        Parameters
+        ----------
+        x : array-like
+            the squares of the input values
+        """
         return numpy.where( xsq <= 1, 1.0 - xsq, 0.0 )
 
     def partial( self, x ):
+        """
+        Return the partial derivative wrt the input values.
+
+        Parameters
+        ----------
+        x : array-like
+            the input values
+        """
         return numpy.where( numpy.abs( x ) <= 1, -2 * x, 0.0 )
 
     def isBound( self ):
+        """ Return True """
         return True
 
     def name( self ):
+        """ Return the name of the kernel """
         return str( "Parabola: ( 1-x^2 ) if |x| < 1 else 0" )
 
 
