@@ -3,11 +3,11 @@ import numpy as numpy
 from .Kernel import Kernel
 
 __author__ = "Do Kester"
-__year__ = 2017
+__year__ = 2025
 __license__ = "GPL3"
-__version__ = "0.9"
-__maintainer__ = "Do"
-__status__ = "Development"
+__version__ = "3.2.4"
+__url__ = "https://dokester.github.io/BayesicFitting/"
+__status__ = "Perpetual Beta"
 
 #  *
 #  *    This file is part of the BayesicFitting package.
@@ -28,14 +28,13 @@ __status__ = "Development"
 #  * Science System (HCSS), also under GPL3.
 #  *
 #  *    2013 - 2014 Do Kester, SRON (Java code)
-#  *    2016 - 2017 Do Kester
+#  *    2016 - 2025 Do Kester
 
 class Tricube( Kernel ):
     """
     Tricube is a Kernel function between [-1,1]; it is 0 elsewhere.
 
-        K( x ) = ( 1 - |x|^3 )^3        if |x| < 1
-                 0                      elsewhere
+     K( x ) = ( 1 - |x|^3 )^3  if |x| < 1 else 0
 
     """
     def __init__( self ) :
@@ -49,19 +48,37 @@ class Tricube( Kernel ):
         super( Tricube, self ).__init__( integral=81.0/70.0, fwhm=1.18176021 )
 
     def result( self, x ):
+        """
+        Return the result for input values.
+
+        Parameters
+        ----------
+        x : array-like
+            input values
+        """
         ax = numpy.abs( x )
         res = numpy.where( ax <= 1, 1 - ax * ax * ax, 0.0 )
         return res * res * res
 
     def partial( self, x ):
+        """
+        Return the partial derivative wrt the input values.
+
+        Parameters
+        ----------
+        x : array-like
+            the input values
+        """
         ax = numpy.abs( x )
         u = 1.0 - ax * ax * ax
         return numpy.where( ax <= 1, -9 * u * u * ax * ax * numpy.sign( x ), 0.0 )
 
     def isBound( self ):
+        """ Return True """
         return True
 
     def name( self ):
+        """ Return the name of the kernel """
         return str( "Tricube: ( 1 - |x|^3 )^3 if |x| < 1 else 0" )
 
 
