@@ -3,11 +3,11 @@ import numpy as numpy
 from .Kernel import Kernel
 
 __author__ = "Do Kester"
-__year__ = 2017
+__year__ = 2025
 __license__ = "GPL3"
-__version__ = "0.9"
-__maintainer__ = "Do"
-__status__ = "Development"
+__version__ = "3.2.4"
+__url__ = "https://dokester.github.io/BayesicFitting/"
+__status__ = "Perpetual Beta"
 
 #  *
 #  *    This file is part of the BayesicFitting package.
@@ -28,7 +28,7 @@ __status__ = "Development"
 #  * Science System (HCSS), also under GPL3.
 #  *
 #  *    2010 - 2014 Do Kester, SRON (Java code)
-#  *    2016 - 2017 Do Kester
+#  *    2016 - 2025 Do Kester
 
 class Uniform( Kernel ):
     """
@@ -49,19 +49,45 @@ class Uniform( Kernel ):
         super( Uniform, self ).__init__( integral=2.0, fwhm=2.0 )
 
     def result( self, x ):
+        """
+        Return the result for input values.
+
+        Parameters
+        ----------
+        x : array-like
+            input values
+        """
         ax = numpy.abs( x )
         return numpy.where( ax < 1, 1.0, numpy.where( ax == 1, 0.5, 0.0 ) )
 
     def resultsq( self, xsq ):
+        """
+        Return the result for input values. Same as result.
+
+        Parameters
+        ----------
+        xsq : array-like
+            input values
+        """
         return self.result( xsq )                   #  the same
 
     def partial( self, x ):
+        """
+        Return the partial derivative wrt the input values.
+
+        Parameters
+        ----------
+        x : array-like
+            the input values
+        """
         return numpy.zeros_like( x )
 
     def isBound( self ):
+        """ Return True """
         return True
 
     def name( self ):
+        """ Return the name of the kernel """
         return str( "Uniform: 1 if |x| < 1 else 0" )
 
 
