@@ -78,6 +78,7 @@ class Test( unittest.TestCase ):
         m = GaussModel()
         p = PolynomialModel( 2 )
         m1 = m | p
+        Tools.printclass( m1 )
         self.assertTrue( isinstance( m1, Model ) )
         self.assertTrue( m1.npchain == 6 )
 
@@ -96,10 +97,13 @@ class Test( unittest.TestCase ):
         print( hi )
 
         m1 = p + m
-        lo = [m1.getPrior(k).lowLimit for k in range( m1.npchain )]
-        print( lo )
-        hi = [m1.getPrior(k).highLimit for k in range( m1.npchain )]
-        print( hi )
+
+        ( lo, hi ) = m1.getLimits()
+        print( "lolim   ", lo )
+        print( "hilim   ", hi )
+        self.assertTrue( len( lo ) == 7 )
+        self.assertTrue( len( hi ) == 7 )
+
 
         r = RepeatingModel( 3, m )
         print( r.npchain, m.npchain, m.npbase )
@@ -112,13 +116,20 @@ class Test( unittest.TestCase ):
         Tools.printclass( r )
         for k in range( r.npchain ) :
             print( k, r.par2model( k ) )
-        lo = [r.getPrior(k).lowLimit for k in range( r.npchain )]
-        print( lo )
+        ( lo, hi ) = r.getLimits()
+        print( "lolim   ", lo )
+        print( "hilim   ", hi )
+        self.assertTrue( len( lo ) == 9 )
+        self.assertTrue( len( hi ) == 9 )
+
+
         m1 = p + r
-        lo = [m1.getPrior(k).lowLimit for k in range( m1.npchain )]
-        print( lo )
-        hi = [m1.getPrior(k).highLimit for k in range( m1.npchain )]
-        print( hi )
+        ( lo, hi ) = m1.getLimits()
+        print( "lolim   ", lo )
+        print( "hilim   ", hi )
+        self.assertTrue( len( lo ) == 13 )
+        self.assertTrue( len( hi ) == 13 )
+
 
         r = RepeatingModel( 3, m, same=2 )
         print( r.npchain, m.npchain, m.npbase )
@@ -133,10 +144,13 @@ class Test( unittest.TestCase ):
         lo = [r.getPrior(k).lowLimit for k in range( r.npchain )]
         print( lo )
         m1 = p + r
-        lo = [m1.getPrior(k).lowLimit for k in range( m1.npchain )]
-        print( lo )
-        hi = [m1.getPrior(k).highLimit for k in range( m1.npchain )]
-        print( hi )
+        ( lo, hi ) = m1.getLimits()
+        print( "lolim   ", lo )
+        print( "hilim   ", hi )
+        self.assertTrue( len( lo ) == 11 )
+        self.assertTrue( len( hi ) == 11 )
+
+
 
         m = GaussModel()
         r = RepeatingModel( 3, m, same=2 )
@@ -154,6 +168,12 @@ class Test( unittest.TestCase ):
         lo = [r.getPrior(k).lowLimit for k in range( r.npchain )]
         print( lo )
         m1 = p + r
+        ( lo, hi ) = m1.getLimits()
+        print( "lolim   ", lo )
+        print( "hilim   ", hi )
+        self.assertTrue( len( lo ) == m1.npchain )
+        self.assertTrue( len( hi ) == m1.npchain )
+
         lo = [m1.getPrior(k).lowLimit for k in range( m1.npchain )]
         print( lo )
         hi = [m1.getPrior(k).highLimit for k in range( m1.npchain )]
@@ -162,6 +182,12 @@ class Test( unittest.TestCase ):
         h = HarmonicModel( 3 )
         h.setLimits( lowLimits=[-110,-111], highLimits=[110,111] )
         m1 = p + h
+        ( lo, hi ) = m1.getLimits()
+        print( "lolim   ", lo )
+        print( "hilim   ", hi )
+        self.assertTrue( len( lo ) == m1.npchain )
+        self.assertTrue( len( hi ) == m1.npchain )
+
         lo = [m1.getPrior(k).lowLimit for k in range( m1.npchain )]
         print( lo )
         hi = [m1.getPrior(k).highLimit for k in range( m1.npchain )]
@@ -170,10 +196,12 @@ class Test( unittest.TestCase ):
         h = HarmonicDynamicModel( 3 )
         h.setLimits( lowLimits=[-110,-111], highLimits=[110,111] )
         m1 = p + h
-        lo = [m1.getPrior(k).lowLimit for k in range( m1.npchain )]
-        print( lo )
-        hi = [m1.getPrior(k).highLimit for k in range( m1.npchain )]
-        print( hi )
+        ( lo, hi ) = m1.getLimits()
+        print( "lolim   ", lo )
+        print( "hilim   ", hi )
+        self.assertTrue( len( lo ) == m1.npchain )
+        self.assertTrue( len( hi ) == m1.npchain )
+
 
 
     def testOneModel( self ):
@@ -303,19 +331,26 @@ class Test( unittest.TestCase ):
         stdModeltest( model, p, x=x, plot=self.doplot )
 
     def testPipe3( self ) :
-        model = SoftMaxModel( ndim=1, ndout=2 )
+        model = StellarOrbitModel( )
         model |= PolySurfaceModel( 3 )
 
         print( model.npars )
-#        print( model )
+        printclass( model )
+        printclass( model._next )
 
-#        print( PolySurfaceModel( 2 ) )
-#        print( PolySurfaceModel( 3 ) )
-
-        p = numpy.asarray( [0.0, 0.4, 0.2, 1.0, 0.0, 0.0, 0.4, 0.2, 1.0, 0.0, 0.0, 0.4] )
+        p = numpy.asarray( [0.0, 0.4, 0.2, 1.0, 0.0, 0.0, 0.4, 0.2, 1.0, 0.0, 0.0, 0.4,
+                            -0.1, -0.2, 0.3, 0.0, 0.0] )
         x = numpy.linspace( 0, 10, 101, dtype=float )
 
         y = model.result( x, p )
+        print( y.shape )
+        print( fmt( y ) )
+        pp = model.partial( x, p )
+        print( pp.shape )
+        print( fmt( pp ) )
+        dd = model.derivative( x, p )
+        print( dd.shape )
+        print( fmt( dd ) )
 
         stdModeltest( model, p, x=x, plot=self.doplot )
 
@@ -501,7 +536,7 @@ class Test( unittest.TestCase ):
 
 
     def suite( cls ):
-        return unittest.TestCase.suite( CompoundModelTest.__class__ )
+        return unittest.TestCase.suite( CompoundModel.__class__ )
 
 
 if __name__ == '__main__':
